@@ -23,7 +23,7 @@ use parent qw(
   WWW::YoutubeViewer::CommentThreads
   WWW::YoutubeViewer::Authentication
   WWW::YoutubeViewer::VideoCategories
-  );
+);
 
 =head1 NAME
 
@@ -31,7 +31,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.8.1';
+our $VERSION = '3.8.2';
 
 =head1 SYNOPSIS
 
@@ -286,7 +286,7 @@ sub set_lwp_useragent {
 
     require LWP::ConnCache;
     state $cache = LWP::ConnCache->new;
-    $cache->total_capacity(undef);                               # no limit
+    $cache->total_capacity(undef);    # no limit
 
     state $accepted_encodings = do {
         require HTTP::Message;
@@ -548,7 +548,7 @@ sub get_invidious_instances {
 
         my $lwp = LWP::UserAgent->new(timeout => $self->get_timeout);
         $lwp->show_progress(1) if $self->get_debug;
-        my $resp = $lwp->get("https://instances.invidio.us/instances.json");
+        my $resp = $lwp->get("https://api.invidious.io/instances.json");
 
         $resp->is_success() or return;
 
@@ -579,12 +579,15 @@ sub select_good_invidious_instances {
                    'yewtu.be'                 => 1,
                    'invidious.tube'           => 1,
                    'invidiou.site'            => 0,
+                   'invidious.site'           => 1,
+                   'invidious.zee.li'         => 1,
+                   'invidious.048596.xyz'     => 1,
                    'invidious.xyz'            => 1,
                    'vid.mint.lgbt'            => 1,
                    'invidious.ggc-project.de' => 1,
                    'invidious.toot.koeln'     => 1,
-                   'invidious.kavin.rocks'    => 0,
-                   'invidious.snopyta.org'    => 1,
+                   'invidious.kavin.rocks'    => 1,
+                   'invidious.snopyta.org'    => 0,
                   );
 
 #<<<
@@ -633,7 +636,7 @@ sub _extract_from_invidious {
           invidious.site
           invidious.fdn.fr
           invidious.snopyta.org
-          );
+        );
     }
 
     if ($self->get_debug) {
@@ -733,9 +736,9 @@ sub _fallback_extract_urls {
         @formats && return @formats;
     }
 
-    # Use the API of invidio.us
+    # Use the API of invidious
     if ($self->get_debug) {
-        say STDERR ":: Using invidio.us to extract the streaming URLs...";
+        say STDERR ":: Using invidious to extract the streaming URLs...";
     }
 
     push @formats, $self->_extract_from_invidious($videoID);
